@@ -64,6 +64,7 @@ setMethodS3("as.data.frame", "CopyNumberRegions", function(x, ...) {
   data;
 })
 
+
 setMethodS3("extractIGV", "CopyNumberRegions", function(this, ...) {
   data <- as.data.frame(this, ...);
   names <- colnames(data);
@@ -90,6 +91,14 @@ setMethodS3("extractIGV", "CopyNumberRegions", function(this, ...) {
 })
 
 
+setMethodS3("equals", "CopyNumberRegions", function(this, other, ...) {
+  dfThis <- as.data.frame(this);
+  dfOther <- as.data.frame(other);
+  res <- all.equal(dfThis, dfOther);
+  isTRUE(res);
+})
+
+
 setMethodS3("applyRows", "CopyNumberRegions", function(this, FUN, ...) {
   data <- as.data.frame(this);
   res <- vector("list", nrow(data));
@@ -152,6 +161,8 @@ setMethodS3("extractCopyNumberRegions", "default", abstract=TRUE);
 
 ############################################################################
 # HISTORY:
+# 2010-04-06
+# o Added equals() for CopyNumberRegions.
 # 2009-05-16
 # o Now the constructor CopyNumberRegions() coerce numerics only if 
 #   necessary, i.e. it keeps integers if integers, otherwise to doubles.
